Step 4 and 8: Drizzling the Images — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Step 4 and 8: Drizzling the Images

The operation of drizzling each input image needs to be performed twice during processing:
  - single drizzle step: this initial step drizzles each image onto the final output WCS as separate images
  - final drizzle step: this step produces the final combined image based on the cosmic-ray masks determined by MultiDrizzle

`drizzlepac.adrizzle.` `buildDrizParamDict`(configObj, single=True)

`drizzlepac.adrizzle.` `create_output`(filename)

`drizzlepac.adrizzle.` `do_driz`(insci, input_wcs, inwht, output_wcs, outsci, outwht, outcon, expin, in_units, wt_scl, wcslin_pscale=1.0, uniqid=1, pixfrac=1.0, kernel='square', fillval='INDEF', stepsize=10, wcsmap=None)

  Core routine for performing ‘drizzle’ operation on a single input image All input values will be Python objects such as ndarrays, instead of filenames File handling (input and output) will be performed by calling routine.

`drizzlepac.adrizzle.` `drizFinal`(imageObjectList, output_wcs, configObj, build=None, wcsmap=None, procSteps=None)

`drizzlepac.adrizzle.` `drizSeparate`(imageObjectList, output_wcs, configObj, wcsmap=None, procSteps=None)

`drizzlepac.adrizzle.` `drizzle`(input, outdata, wcsmap=None, editpars=False, configObj=None, **input_dict)

`drizzlepac.adrizzle.` `getHelpAsString`()

  Return useful help from a file in the script directory called module.help

`drizzlepac.adrizzle.` `get_data`(filename)

`drizzlepac.adrizzle.` `help`()

`drizzlepac.adrizzle.` `mergeDQarray`(maskname, dqarr)

  Merge static or CR mask with mask created from DQ array on-the-fly here.

`drizzlepac.adrizzle.` `run`(configObj, wcsmap=None)

  Interface for running ‘wdrizzle’ from TEAL or Python command-line.

  This code performs all file I/O to set up the use of the drizzle code for a single exposure to replicate the functionality of the original ‘wdrizzle’.

`drizzlepac.adrizzle.` `run_driz`(imageObjectList, output_wcs, paramDict, single, build, wcsmap=None)

  Perform drizzle operation on input to create output. The input parameters originally was a list of dictionaries, one for each input, that matches the primary parameters for an IRAF drizzle task.

  This method would then loop over all the entries in the list and run ‘drizzle’ for each entry.

  Parameters required for input in paramDict:
    build,single,units,wt_scl,pixfrac,kernel,fillval, rot,scale,xsh,ysh,blotnx,blotny,outnx,outny,data

`drizzlepac.adrizzle.` `run_driz_chip`(img, virtual_outputs, chip, output_wcs, outwcs, template, paramDict, single, doWrite, build, _versions, _numctx, _nplanes, _numchips, _outsci, _outwht, _outctx, _hdrlist, wcsmap)

  Perform the drizzle operation on a single chip. This is separated out from run_driz_img() so as to keep together the entirety of the code which is inside the loop over chips. See the run_driz() code for more documentation.

`drizzlepac.adrizzle.` `run_driz_img`(img, virtual_outputs, chiplist, output_wcs, outwcs, template, paramDict, single, num_in_prod, build, _versions, _numctx, _nplanes, chipIdxCopy, _outsci, _outwht, _outctx, _hdrlist, wcsmap)

  Perform the drizzle operation on a single image. This is separated out from run_driz() so as to keep together the entirety of the code which is inside the loop over images. See the run_driz() code for more documentation.

`drizzlepac.adrizzle.` `updateInputDQArray`(dqfile, dq_extn, chip, crmaskname, cr_bits_value)

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »